

.. _dim_api:

----------
Dimension
----------

.. currentmodule:: csdmpy.dimensions


.. autoclass:: Dimension
    :show-inheritance:

    .. rubric:: Attributes Summary

    .. autosummary::
        ~Dimension.type
        ~Dimension.description
        ~Dimension.application
        ~Dimension.coordinates
        ~Dimension.absolute_coordinates
        ~Dimension.count
        ~Dimension.increment
        ~Dimension.coordinates_offset
        ~Dimension.origin_offset
        ~Dimension.complex_fft
        ~Dimension.quantity_name
        ~Dimension.label
        ~Dimension.labels
        ~Dimension.period
        ~Dimension.axis_label
        ~Dimension.data_structure

    .. rubric:: Methods Summary

    .. autosummary::
        ~Dimension.to


    .. rubric:: Attributes Documentation

    .. autoattribute:: type
    .. autoattribute:: description
    .. autoattribute:: application
    .. autoattribute:: coordinates
    .. autoattribute:: absolute_coordinates
    .. autoattribute:: count
    .. autoattribute:: increment
    .. autoattribute:: coordinates_offset
    .. autoattribute:: origin_offset
    .. autoattribute:: complex_fft
    .. autoattribute:: quantity_name
    .. autoattribute:: label
    .. autoattribute:: labels
    .. autoattribute:: period
    .. autoattribute:: axis_label
    .. autoattribute:: data_structure


    .. rubric:: Method Documentation

    .. automethod:: to
